@@ -434,7 +434,7 @@ c+++++++ check if the user has requested an interrupt
                tt4=1.d0-tt3
                call cdfbet(1,tt1,tt2,tt3,tt4,a0,b0,status,bound)
                if(status.ne.0)then
-                  call rexit("Error in tdpdensitypl")      
+                  call rexit("Error in 'tdpdensitypl'")      
                end if
                tmp1=tt1
 
@@ -448,7 +448,7 @@ c+++++++ check if the user has requested an interrupt
                tt4=1.d0-tt3
                call cdfbet(1,tt1,tt2,tt3,tt4,a0,b0,status,bound)
                if(status.ne.0)then
-                  call rexit("Error in tdpdensitypl")      
+                  call rexit("Error in 'tdpdensitypl'")      
                end if
                tmp2=tt1
  
@@ -457,7 +457,7 @@ c+++++++ check if the user has requested an interrupt
                call cdfbet(2,tmp3,1.d0-tmp3,yrand,yrand2,a0,b0,
      &                     status,bound)
                if(status.ne.0)then
-                  call rexit("Error in tdpdensitypl")      
+                  call rexit("Error in 'tdpdensitypl'")      
                end if
             end if
             
